@@ -1,15 +1,15 @@
 
-from twisted.internet.defer import succeed, maybeDeferred
-
-from synapse.util import Clock
-from synapse.events import FrozenEvent
-from synapse.types import Requester, UserID
-
-from tests import unittest
-from tests.server import setup_test_homeserver, ThreadedMemoryReactorClock
-
 from mock import Mock
 
+from twisted.internet.defer import maybeDeferred, succeed
+
+from synapse.events import FrozenEvent
+from synapse.types import Requester, UserID
+from synapse.util import Clock
+
+from tests import unittest
+from tests.server import ThreadedMemoryReactorClock, setup_test_homeserver
+
 
 class MessageAcceptTests(unittest.TestCase):
     def setUp(self):
